package com.persagy.fm.person.dao;

import com.persagy.fm.person.model.Person;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.persagy.fm.person.model.dto.*;
import org.apache.ibatis.annotations.Mapper;

import javax.naming.Name;
import java.util.List;

/**
 * 人员(Person)dao层
 *
 * @author lixing
 * @version V1.0 2021-03-15 17:20:32
 */
@Mapper
public interface PersonMapper extends BaseMapper<Person> {
    /**
     * 查询人员列表
     *
     * @param pageQueryPersonDTO 分页查询条件
     * @return 人员列表
     * @author lixing
     * @version V1.0 2021/3/23 5:14 下午
     */
    List<Person> queryPersonList(PageQueryPersonDTO pageQueryPersonDTO);

    /**
     * 查询部门下的人员列表
     *
     * @param pageQueryByDepIdsDTO 查询条件
     * @return 人员列表
     * @author lixing
     * @version V1.0 2021/3/23 5:14 下午
     */
    List<Person> queryByDepIds(PageQueryByDepIdsDTO pageQueryByDepIdsDTO);

    /**
     * 查询人员数量
     *
     * @param pageQueryByDepIdsDTO 查询条件
     * @return 人员总条数
     * @author lixing
     * @version V1.0 2021/3/23 5:14 下午
     */
    int queryCountByDepIds(PageQueryByDepIdsDTO pageQueryByDepIdsDTO);

    /**
     * 查询人员数量
     *
     * @param pageQueryPersonDTO 分页查询条件
     * @return 人员总条数
     * @author lixing
     * @version V1.0 2021/3/23 5:14 下午
     */
    int queryCount(PageQueryPersonDTO pageQueryPersonDTO);

    /**
     * 根据人员姓名或用户名查询人员列表
     *
     * @param pageQueryPersonDTO 分页查询条件
     * @return 人员列表
     * @author lixing
     * @version V1.0 2021/4/14 5:53 下午
     */
    List<Person> queryPersonListByNameOrUserName(PageQueryPersonByNameOrUserNameDTO pageQueryPersonDTO);

    /**
     * 根据人员姓名或用户名查询人员数量
     *
     * @param pageQueryPersonDTO 分页查询条件
     * @return 人员列表
     * @author lixing
     * @version V1.0 2021/4/14 5:53 下午
     */
    int queryCountByNameOrUserName(PageQueryPersonByNameOrUserNameDTO pageQueryPersonDTO);

    /**
     * 快速查询人员姓名
     *
     * @param nameQuickSearchDTO 快速查询人员姓名入参
     * @return 人员列表
     * @author lixing
     * @version V1.0 2021/4/1 11:49 上午
     */
    List<Person> queryPersonNameList(NameQuickSearchDTO nameQuickSearchDTO);
}
