package com.persagy.fm.person.model;

import com.persagy.fm.common.model.vo.SimpleObjVO;
import com.persagy.fm.person.jms.model.AccountCreateMsg;
import com.persagy.fm.person.model.dto.*;
import com.persagy.fm.person.model.vo.AccountInfoVO;
import com.persagy.fm.person.model.vo.ResponsePersonItemVO;
import com.persagy.fm.person.model.vo.ResponsePersonListItemVO;
import com.persagy.fm.person.model.vo.SimplePersonListItemVO;
import com.persagy.fm.saas.account.model.dto.AddSaasAccountDTO;
import com.persagy.fm.saas.account.model.dto.PageQuerySaasAccountByRoleIdsDTO;
import com.persagy.fm.saas.account.model.dto.UpdateSaasAccountDTO;
import com.persagy.fm.saas.account.model.vo.SaasAccountListItemVO;
import com.persagy.fm.saas.project.model.SaasProject;
import com.persagy.fm.saas.project.model.vo.ProjectVO;
import com.persagy.fm.workresume.model.dto.PageQueryWorkResumeDTO;
import org.mapstruct.*;
import org.mapstruct.factory.Mappers;

import java.util.List;

/**
 * 人员(Person) dto、vo、do转换工具类
 *
 * @author lixing
 * @version V1.0 2021-03-15 17:20:33 2021-03-15 17:20:33
 */
@Mapper(nullValueMappingStrategy = NullValueMappingStrategy.RETURN_DEFAULT,
        nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS)
public interface ConvertPersonTool {

    ConvertPersonTool INSTANCE = Mappers.getMapper(ConvertPersonTool.class);

    /**
     * do转换为ResponseItemVO
     *
     * @param person do对象
     * @return ResponseItemVO
     * @author lixing
     * @version V1.0 2021-03-15 17:20:33
     */
    ResponsePersonItemVO convert2ResponseItemDTO(Person person);

    /**
     * do转换为ResponseListItemVO
     *
     * @param person do对象
     * @return ResponseListItemVO
     * @author lixing
     * @version V1.0 2021-03-15 17:20:33
     */
    ResponsePersonListItemVO convert2ResponseListItemDTO(Person person);

    /**
     * do列表转换为ResponseListItemVO列表
     *
     * @param personList do列表
     * @return ResponseListItemVO列表
     * @author lixing
     * @version V1.0 2021-03-15 17:20:33
     */
    List<ResponsePersonListItemVO> convert2List(List<Person> personList);

    /**
     * addDTO转换为do
     *
     * @param addPerson4FrontEndDTO addDTO
     * @return 要创建的do对象
     * @author lixing
     * @version V1.0 2021-03-15 17:20:33
     */
    Person convertAddDto2Entity(AddPerson4FrontEndDTO addPerson4FrontEndDTO);

    /**
     * updateDTO转换为实体
     *
     * @param person          更新前的do对象
     * @param updatePerson4FrontEndDTO updateDTO
     * @return 更新后的do对象
     * @author lixing
     * @version V1.0 2021-03-15 17:20:33
     */
    Person convertUpdateDto2Entity(@MappingTarget Person person, UpdatePerson4FrontEndDTO updatePerson4FrontEndDTO);

    /**
     * 分页查询部门下的人员入参转换为查询工作信息入参
     *
     * @param pageQueryPersonDTO 分页查询部门下的人员入参
     * @return 查询工作信息入参
     * @author lixing
     * @version V1.0 2021/3/15 5:32 下午
     */
    PageQueryWorkResumeDTO convert2PageQueryWorkResumeDTO(PageQueryPersonDTO pageQueryPersonDTO);

    /**
     * 账号创建消息转换为创建人员入参
     *
     * @param accountCreateMsg 账号创建消息
     * @return 创建人员入参
     * @author lixing
     * @version V1.0 2021/3/22 7:59 下午
     */
    @Mappings({
            @Mapping(source = "id", target = "id", ignore = true),
            @Mapping(source = "id", target = "accountId"),
            @Mapping(source = "username", target = "name"),
            @Mapping(source = "username", target = "username"),
            @Mapping(source = "username", target = "namePinyin")
    })
    Person convert2Entity(AccountCreateMsg accountCreateMsg);

    /**
     * 实体对象列表转换为SimplePersonListItemVO列表
     *
     * @param personList 人员对象列表
     * @return 人名列表
     * @author lixing
     * @version V1.0 2021/3/22 7:58 下午
     */
    List<SimplePersonListItemVO> convert2SimpleList(List<Person> personList);

    /**
     * 实体对象转换为SimplePersonListItemVO
     *
     * @param person 实体对象
     * @return SimplePersonListItemVO
     * @author lixing
     * @version V1.0 2021/3/22 8:01 下午
     */
    SimplePersonListItemVO convert2SimpleListItem(Person person);

    /**
     * addPersonDTO转换为addSaasAccountDTO
     *
     * @param addPerson4FrontEndDTO 添加人员的入参
     * @return 创建账号的入参
     * @author lixing
     * @version V1.0 2021/4/6 3:06 下午
     */
    @Mapping(source = "expireDate", target = "validEndTime")
    AddSaasAccountDTO convert2AddSaasAccountDTO(AddPerson4FrontEndDTO addPerson4FrontEndDTO);

    /**
     * 账号信息和更新人员入参转换为更新账号入参
     *
     * @param account 账号信息
     * @param updatePerson4FrontEndDTO 更新人员入参
     * @return 更新账号入参
     * @author lixing
     * @version V1.0 2021/4/6 4:55 下午
     */
    @Mappings({
            @Mapping(target = "accountId", source = "account.id"),
            @Mapping(target = "accountType", source = "account.accountType"),
            @Mapping(target = "accountSource", source = "account.accountSource"),
            @Mapping(target = "headPortrait", source = "account.headPortrait"),
            @Mapping(target = "validStartTime", source = "account.validStartTime"),
            @Mapping(target = "remark", source = "account.remark"),
            @Mapping(target = "username", source = "updatePerson4FrontEndDTO.username"),
            @Mapping(target = "phoneNum", source = "updatePerson4FrontEndDTO.phoneNum"),
            @Mapping(target = "mail", source = "updatePerson4FrontEndDTO.mail"),
            @Mapping(target = "validEndTime", source = "updatePerson4FrontEndDTO.expireDate")
    })
    UpdateSaasAccountDTO convert2UpdateSaasAccountDTO(SaasAccountListItemVO account, UpdatePerson4FrontEndDTO updatePerson4FrontEndDTO);

    /**
     * 运维系统项目列表转换为展示给前端的ProjectVO列表
     *
     * @param saasProjects 运维系统项目列表
     * @return ProjectVO列表
     * @author lixing
     * @version V1.0 2021/4/9 4:45 下午
     */
    List<ProjectVO> convert2ProjectVoList(List<SaasProject> saasProjects);

    /**
     * 运维系统项目转换为展示给前端的simpleProjectVO
     *
     * @param saasProject 运维系统项目
     * @return simpleProjectVO
     * @author lixing
     * @version V1.0 2021/4/9 4:47 下午
     */
    @Mappings({
            @Mapping(target = "id", source = "projectId"),
            @Mapping(target = "name", source = "projectName")
    })
    SimpleObjVO convert2SimpleProjectVO(SaasProject saasProject);

    /**
     * 运维系统项目转换为展示给前端的ProjectVO
     *
     * @param saasProject 运维系统项目
     * @return ProjectVO
     * @author lixing
     * @version V1.0 2021/4/9 4:47 下午
     */
    @Mappings({
            @Mapping(target = "id", source = "projectId"),
            @Mapping(target = "name", source = "projectName")
    })
    ProjectVO convert2ProjectVO(SaasProject saasProject);

    /**
     * AddPerson4BackEndDTO 转换为 AddPerson4FrontEndDTO
     *
     * @param addPerson4BackEndDTO 给后端使用的添加人员dto
     * @return AddPerson4FrontEndDTO 给前端使用的添加人员dto
     * @author lixing
     * @version V1.0 2021/4/20 10:06 上午
     */
    AddPerson4FrontEndDTO convert2AddPerson4FrontEndDTO(AddPerson4BackEndDTO addPerson4BackEndDTO);

    /**
     * pageQueryByDepIdDTO 转换为 PageQueryByDepIdsDTO
     *
     * @param pageQueryByDepIdDTO 根据部门id查询入参
     * @return 根据部门id列表查询入参
     * @author lixing
     * @version V1.0 2021/4/29 4:51 下午
     */
    PageQueryByDepIdsDTO convert2PageQueryByDepIdsDTO(PageQueryByDepIdDTO pageQueryByDepIdDTO);

    /**
     * 根据角色id查询人员列表入参转换为根据角色id查询账号列表入参
     *
     * @param pageQueryByRoleIdsDTO 根据角色id查询人员列表入参
     * @return 根据角色id查询账号列表入参
     * @author lixing
     * @version V1.0 2021/5/8 5:30 下午
     */
    PageQuerySaasAccountByRoleIdsDTO convert2PageQuerySaasAccountByRoleIdsDTO(
            PageQueryByRoleIdsDTO pageQueryByRoleIdsDTO);

    /**
     * 转换为账号信息
     *
     * @param saasAccountListItemVO 账号vo类
     * @param person 人员实体
     * @return 账号信息
     * @author lixing
     * @version V1.0 2021/5/8 6:03 下午
     */
    @Mappings({
            @Mapping(source = "saasAccountListItemVO.id", target = "accountId"),
            @Mapping(source = "saasAccountListItemVO.username", target = "username"),
            @Mapping(source = "saasAccountListItemVO.headPortrait", target = "headPortrait"),
            @Mapping(source = "saasAccountListItemVO.phoneNum", target = "phoneNum"),
            @Mapping(source = "saasAccountListItemVO.mail", target = "mail"),
            @Mapping(source = "saasAccountListItemVO.valid", target = "valid", qualifiedByName = "accountValid2Str"),
            @Mapping(source = "person.id", target = "personId"),
            @Mapping(source = "person.name", target = "name"),
    })
    AccountInfoVO convert2AccountInfoVO(SaasAccountListItemVO saasAccountListItemVO, Person person);

    /**
     * 账号是否有效转换为字符串
     *
     * @param valid 账号是否有效（0/1）
     * @return 有效/失效
     * @author lixing
     * @version V1.0 2021/5/8 6:25 下午
     */
    @Named("valid2Str")
    default String accountValid2Str(Integer valid){
      if(1 == valid){
       return "有效";
      } 
      return "失效";
    }
}

