package com.persagy.fm.person.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.persagy.fm.common.model.vo.SimpleObjVO;
import com.persagy.fm.person.model.Person;
import com.persagy.fm.person.model.dto.*;
import com.persagy.fm.person.model.vo.AccountInfoVO;
import com.persagy.fm.person.model.vo.LatestJobNumberVO;
import com.persagy.fm.person.model.vo.ResponsePersonItemVO;
import com.persagy.fm.person.model.vo.ResponsePersonListItemVO;

import java.util.List;

/**
 * 人员(Person) 查询接口
 *
 * @author lixing
 * @version V1.0 2021-03-15 17:20:31
 */
public interface IPersonQueryService {
    /**
     * 获取最新的工号
     *
     * @return 工号vo类
     * @author lixing
     * @version V1.0 2021/4/7 10:42 上午
     */
    LatestJobNumberVO queryLatestJobNumber();

    /**
     * 人员基本属性详情
     *
     * @param id 主键
     * @return 人员do对象
     * @author lixing
     * @version V1.0 2021-03-15 17:20:31
     */
    Person queryPersonProfile(String id);

    /**
     * 人员详情
     *
     * @param id 主键
     * @return 人员do对象
     * @author lixing
     * @version V1.0 2021-03-15 17:20:31
     */
    ResponsePersonItemVO queryPersonDetail(String id);

    /**
     * 根据直接领导id，获取直接领导信息
     *
     * @param leaderId 直接领导id
     * @return 直接领导信息
     * @author lixing
     * @version V1.0 2021/4/1 2:53 下午
     */
    SimpleObjVO getLeaderVO(String leaderId);

    /**
     * 人员详情
     *
     * @param id 人员主键
     * @param depId 部门主键
     * @return 人员do对象
     * @author lixing
     * @version V1.0 2021-03-15 17:20:31
     */
    ResponsePersonItemVO queryPersonDetail(String id, String depId);

    /**
     * 通过主键数组查询人员
     *
     * @param ids 主键List
     * @return 人员列表
     */
    List<Person> queryByIds(List<String> ids);

    /**
     * 通过主键数组查询人员
     *
     * @param ids 主键List
     * @return 人员详情分页列表
     */
    IPage<ResponsePersonListItemVO> queryDetailByIds(List<String> ids);

    /**
     * 根据身份证号查询人员
     *
     * @param idCard 身份证号
     * @return 人员列表
     * @author lixing
     * @version V1.0 2021/4/1 3:00 下午
     */
    List<Person> queryByIdCard(String idCard);

    /**
     * 根据账号查询人员
     *
     * @param username 账号
     * @return 人员列表
     * @author lixing
     * @version V1.0 2021/4/1 3:00 下午
     */
    List<Person> queryByUsername(String username);

    /**
     * 根据工号查询人员
     *
     * @param jobNumber 工号
     * @return 人员列表
     * @author lixing
     * @version V1.0 2021/4/1 3:00 下午
     */
    List<Person> queryByJobNumber(String jobNumber);

    /**
     * 分页查询人员
     *
     * @param pageQueryPersonDTO pageQueryDTO
     * @return IPage<Person>
     * @author lixing
     * @version V1.0 2021-03-15 17:20:31
     */
    IPage<ResponsePersonListItemVO> pageQueryPerson(PageQueryPersonDTO pageQueryPersonDTO);

    /**
     * 根据账号id，查询人员信息
     *
     * @param accountId 账号id
     * @return 人员
     * @author lixing
     * @version V1.0 2021/3/30 5:00 下午
     */
    Person queryByAccountId(String accountId);

    /**
     * 根据账号id，查询人员信息
     *
     * @param accountId 账号id
     * @param depId 部门id
     * @return 人员详情
     * @author lixing
     * @version V1.0 2021/3/30 5:00 下午
     */
    ResponsePersonItemVO queryDetailByAccountId(String accountId, String depId);

    /**
     * 快速查询人名
     *
     * @param nameQuickSearchDTO 快速查询人名入参
     * @return 匹配到的人名列表
     * @author lixing
     * @version V1.0 2021/3/22 7:57 下午
     */
    List<Person> nameQuickSearch(NameQuickSearchDTO nameQuickSearchDTO);

    /**
     * 根据专业id查询人员
     *
     * @param professionId 专业id
     * @return 人员列表
     * @author lixing
     * @version V1.0 2021/4/11 9:50 下午
     */
    List<Person> queryByProfessionId(String professionId);

    /**
     * 根据直接上级id查询人员
     *
     * @param leaderId 直接上级id
     * @return 人员列表
     * @author lixing
     * @version V1.0 2021/4/11 9:50 下午
     */
    List<Person> queryByLeader(Long leaderId);

    /**
     * 根据名称或账号查询
     *
     * @param pageQueryPersonDTO 查询参数
     * @return 分页列表
     * @author lixing
     * @version V1.0 2021/4/14 4:32 下午
     */
    IPage<ResponsePersonListItemVO> pageQueryByNameOrUserName(PageQueryPersonByNameOrUserNameDTO pageQueryPersonDTO);

    /**
     * 根据账号查询
     *
     * @param queryByUserNameDTO 查询参数
     * @return 分页列表
     * @author lixing
     * @version V1.0 2021/4/22 3:28 下午
     */
    IPage<ResponsePersonListItemVO> queryByUserName(QueryByUserNameDTO queryByUserNameDTO);

    /**
     * 根据姓名查询
     *
     * @param queryByNameDTO 查询参数
     * @return 分页列表
     * @author lixing
     * @version V1.0 2021/4/25 3:04 下午
     */
    IPage<ResponsePersonListItemVO> queryByName(QueryByNameDTO queryByNameDTO);

    /**
     * 查询人员的账号id
     *
     * @param id 人员id
     * @return 人员的账号id
     * @author lixing
     * @version V1.0 2021/4/29 11:53 上午
     */
    String queryAccountId(String id);

    /**
     * 根据部门id查询人员
     *
     * @param pageQueryByDepIdDTO 查询入参
     * @return 人员分页列表
     * @author lixing
     * @version V1.0 2021/4/29 3:27 下午
     */
    IPage<ResponsePersonListItemVO> queryByDepId(PageQueryByDepIdDTO pageQueryByDepIdDTO);

    /**
     * 查询所有人员的姓名列表
     *
     * @param queryAllPersonNameDTO 查询条件
     * @return 人员姓名列表 id -> 名字
     * @author lixing
     * @version V1.0 2021/4/29 5:22 下午
     */
    List<SimpleObjVO> queryAllPersonName(QueryAllPersonNameDTO queryAllPersonNameDTO);

    /**
     * 根据角色id分页查询
     *
     * @param pageQueryByRoleIdsDTO 查询参数
     * @return 人员分页列表
     * @author lixing
     * @version V1.0 2021/4/30 10:27 上午
     */
    IPage<AccountInfoVO> pageQueryByRoleIds(PageQueryByRoleIdsDTO pageQueryByRoleIdsDTO);

    /**
     * 根据账号id列表分页查询
     *
     * @param accountIds 查询参数
     * @return 人员分页列表
     * @author lixing
     * @version V1.0 2021/4/30 10:27 上午
     */
    IPage<ResponsePersonListItemVO> pageQueryByAccountIds(List<String> accountIds);
}
