package com.persagy.fm.person.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.persagy.fm.common.model.vo.SimpleObjVO;
import com.persagy.fm.person.model.Person;
import com.persagy.fm.person.model.dto.*;
import com.persagy.fm.person.model.vo.LatestJobNumberVO;
import com.persagy.fm.person.model.vo.ResponsePersonItemVO;
import com.persagy.fm.person.model.vo.ResponsePersonListItemVO;

import java.util.List;

/**
 * 人员(Person) 创建更新接口
 *
 * @author lixing
 * @version V1.0 2021-03-15 17:20:31
 */
public interface IPersonUpsertService {

    /**
     * 创建人员
     *
     * @param addPerson4FrontEndDTO addDTO
     * @return 人员主键
     * @author lixing
     * @version V1.0 2021-03-15 17:20:31
     */
    String createPerson(AddPerson4FrontEndDTO addPerson4FrontEndDTO);

    /**
     * 创建人员
     *
     * @param person 人员对象
     * @return 人员主键
     * @author lixing
     * @version V1.0 2021-03-15 17:20:31
     */
    String createPerson(Person person);

    /**
     * 更新人员
     *
     * @param updatePerson4FrontEndDTO updateDTO
     * @author lixing
     * @version V1.0 2021-03-15 17:20:31
     */
    void updatePerson(UpdatePerson4FrontEndDTO updatePerson4FrontEndDTO);

    /**
     * 更新人员
     *
     * @param person 人员对象
     * @author lixing
     * @version V1.0 2021/3/30 5:05 下午
     */
    void updatePerson(Person person);

    /**
     * 删除人员
     *
     * @param id 主键
     * @author lixing
     * @version V1.0 2021-03-15 17:20:31
     */
    void deletePerson(String id);

    /**
     * 禁用人员
     *
     * @param personId 人员id
     * @author lixing
     * @version V1.0 2021/3/22 10:39 上午
     */
    void disablePerson(String personId);

    /**
     * 解雇人员
     *
     * @param personId 人员id
     * @author lixing
     * @version V1.0 2021/3/22 10:39 上午
     */
    void dismissPerson(String personId);

    /**
     * 恢复入职
     *
     * @param personId 人员id
     * @author lixing
     * @version V1.0 2021/3/22 10:44 上午
     */
    void rejoinPerson(String personId);

    /**
     * 批量更新人员信息
     *
     * @param batchUpdatePersonDTO 批量更新参数
     * @author lixing
     * @version V1.0 2021/3/22 11:06 上午
     */
    void batchUpdatePeople(BatchUpdatePersonDTO batchUpdatePersonDTO);

    /**
     * 解禁人员
     *
     * @param personId 人员id
     * @author lixing
     * @version V1.0 2021/3/22 10:39 上午
     */
    void enablePerson(String personId);
}
