package com.persagy.fm.person.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.persagy.fm.common.constant.enums.BoolEnum;
import com.persagy.fm.common.constant.enums.ValidEnum;
import com.persagy.fm.common.model.vo.SimpleObjVO;
import com.persagy.fm.common.response.FmResponseContent;
import com.persagy.fm.department.model.Department;
import com.persagy.fm.department.model.vo.DepSimpleObjVO;
import com.persagy.fm.department.service.IDepartmentService;
import com.persagy.fm.person.dao.PersonMapper;
import com.persagy.fm.person.model.ConvertPersonTool;
import com.persagy.fm.person.model.Person;
import com.persagy.fm.person.model.dto.*;
import com.persagy.fm.person.model.vo.AccountInfoVO;
import com.persagy.fm.person.model.vo.LatestJobNumberVO;
import com.persagy.fm.person.model.vo.ResponsePersonItemVO;
import com.persagy.fm.person.model.vo.ResponsePersonListItemVO;
import com.persagy.fm.person.service.IPersonQueryService;
import com.persagy.fm.profession.service.IProfessionService;
import com.persagy.fm.saas.account.constant.enums.ExpireTypeEnum;
import com.persagy.fm.saas.account.model.dto.PageQuerySaasAccountByRoleIdsDTO;
import com.persagy.fm.saas.account.model.vo.SaasAccountListItemVO;
import com.persagy.fm.saas.account.service.ISaasAccountService;
import com.persagy.fm.saas.accountproject.model.SaasAccountProject;
import com.persagy.fm.saas.accountproject.service.ISaasAccountProjectService;
import com.persagy.fm.saas.accountrole.model.vo.AccountRoleVO;
import com.persagy.fm.saas.accountrole.service.ISaasAccountRoleService;
import com.persagy.fm.saas.project.model.SaasProject;
import com.persagy.fm.saas.project.model.vo.ProjectVO;
import com.persagy.fm.saas.project.service.ISaasProjectService;
import com.persagy.fm.workresume.model.WorkResume;
import com.persagy.fm.workresume.service.IWorkResumeService;
import org.apache.commons.lang3.StringUtils;
import org.assertj.core.util.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 人员(Person) service层
 *
 * @author lixing
 * @version V1.0 2021-03-15 17:20:31
 */
@Service
public class PersonQueryServiceImpl extends ServiceImpl<PersonMapper, Person>
        implements IPersonQueryService {
    @Autowired
    private PersonServiceCommonTool personServiceCommonTool;
    @Autowired
    private IWorkResumeService workResumeService;
    @Autowired
    private ISaasAccountService saasAccountService;
    @Autowired
    private PersonMapper personMapper;
    @Autowired
    private ISaasAccountRoleService saasAccountRoleService;
    @Autowired
    private ISaasAccountProjectService saasAccountProjectService;
    @Autowired
    private IProfessionService professionService;
    @Autowired
    private IDepartmentService departmentService;
    @Autowired
    private ISaasProjectService saasProjectService;


    @Override
    public List<Person> queryByIdCard(String idCard) {
        if (StringUtils.isBlank(idCard)) {
            return null;
        }
        QueryWrapper<Person> queryWrapper = personServiceCommonTool.getDefaultPersonQueryWrapper();
        queryWrapper.eq(Person.PROP_ID_NUMBER, idCard);
        return list(queryWrapper);
    }

    @Override
    public List<Person> queryByUsername(String username) {
        if (StringUtils.isBlank(username)) {
            return null;
        }

        QueryWrapper<Person> queryWrapper = personServiceCommonTool.getDefaultPersonQueryWrapper();
        queryWrapper.eq(Person.PROP_USERNAME, username);
        return list(queryWrapper);
    }

    @Override
    public List<Person> queryByJobNumber(String jobNumber) {
        if (StringUtils.isBlank(jobNumber)) {
            return null;
        }
        QueryWrapper<Person> queryWrapper = personServiceCommonTool.getDefaultPersonQueryWrapper();
        queryWrapper.eq(Person.PROP_JOB_NUMBER, jobNumber);
        return list(queryWrapper);
    }


    /**
     * 人员详情
     *
     * @param id 主键
     * @return 部门do类
     * @author lixing
     * @version V1.0 2021-03-15 17:20:31
     */
    @Override
    public Person queryPersonProfile(String id) {
        if (StringUtils.isBlank(id)) {
            throw new IllegalArgumentException("查看Person详情时发生异常, 传入的id为空");
        }
        Person person = getById(id);
        if (person == null) {
            throw new IllegalArgumentException("查看Person详情时发生异常，找不到要查看的记录，id=" + id);
        }
        return person;
    }

    @Override
    public List<Person> queryByIds(List<String> ids) {
        if (CollectionUtils.isEmpty(ids)) {
            return null;
        }
        return listByIds(ids);
    }

    @Override
    public Person queryByAccountId(String accountId) {
        if (StringUtils.isBlank(accountId)) {
            throw new IllegalArgumentException("根据账号id查询人员，账号id为空");
        }
        QueryWrapper<Person> queryWrapper = personServiceCommonTool.getDefaultPersonQueryWrapper();
        queryWrapper.eq(Person.PROP_ACCOUNT_ID, accountId);
        List<Person> people = list(queryWrapper);
        if (!CollectionUtils.isEmpty(people)) {
            return people.get(0);
        }
        return null;
    }


    @Override
    public IPage<ResponsePersonListItemVO> pageQueryPerson(PageQueryPersonDTO pageQueryPersonDTO) {
        List<Person> people = personMapper.queryPersonList(pageQueryPersonDTO);
        int total = personMapper.queryCount(pageQueryPersonDTO);

        return packagePageResult(people, total, pageQueryPersonDTO.getDepId());
    }

    /**
     * 组装分页查询结果
     *
     * @param people 人员列表（单页）
     * @param total  人员总数量
     * @return 分页结果
     * @author lixing
     * @version V1.0 2021/4/14 5:51 下午
     */
    private IPage<ResponsePersonListItemVO> packagePageResult(List<Person> people, int total) {
        return packagePageResult(people, total, null);
    }

    /**
     * 组装分页查询结果
     *
     * @param people 人员列表（单页）
     * @param total  人员总数量
     * @param depId  部门id，如果不根据部门id查询这里传null
     * @return 分页结果
     * @author lixing
     * @version V1.0 2021/4/14 5:51 下午
     */
    private IPage<ResponsePersonListItemVO> packagePageResult(List<Person> people, int total, String depId) {
        return packagePageResult(people, total, depId, null, null);
    }

    /**
     * 组装分页查询结果
     *
     * @param people      人员列表（单页）
     * @param total       人员总数量
     * @param depId       部门id，如果不根据部门id查询这里传null
     * @param hiredState  在职状态，如果不为空，只返回人员对应在职状态的工作信息
     * @param enableState 禁用状态，如果不为空，只返回人员对应禁用状态的工作信息
     * @return 分页结果
     * @author lixing
     * @version V1.0 2021/4/14 5:51 下午
     */
    private IPage<ResponsePersonListItemVO> packagePageResult(
            List<Person> people, int total, String depId, String hiredState, String enableState) {
        IPage<ResponsePersonListItemVO> result = new Page<>();
        if (CollectionUtils.isEmpty(people)) {
            result.setRecords(Lists.newArrayList());
            return result;
        }
        // 准备数据
        List<String> accountIds = people.stream().map(Person::getAccountId).collect(Collectors.toList());
        List<String> peopleIds = people.stream().map(Person::getId).collect(Collectors.toList());
        /* 账号角色的关联信息 */
        Map<String, AccountRoleVO> accountRoleVoMap = saasAccountRoleService.
                queryAccountRoleVoMapByAccountIdList(accountIds);
        /* 人员的工作信息 */
        List<WorkResume> workResumes = workResumeService.queryWorkResumeListByPersonIdList(peopleIds);
        /* 账号的信息 */
        List<SaasAccountListItemVO> saasAccountListItemVOS = saasAccountService.querySaasAccountListByAccountIds(accountIds);
        Map<String, SaasAccountListItemVO> accountInfoMap = saasAccountListItemVOS.stream().
                collect(Collectors.toMap(SaasAccountListItemVO::getId, itemVO -> itemVO, (k1, k2) -> k1));

        /* 数据转换 */
        // 设置人员基本信息
        List<ResponsePersonListItemVO> responsePersonListItems = ConvertPersonTool.INSTANCE.convert2List(people);

        for (ResponsePersonListItemVO responsePersonListItem : responsePersonListItems) {
            // 设置人员主岗副岗信息
            if (accountRoleVoMap != null) {
                AccountRoleVO accountRoleVO = accountRoleVoMap.get(responsePersonListItem.getAccountId());
                if (accountRoleVO != null) {
                    responsePersonListItem.setMainDuty(accountRoleVO.getMainDuty());
                    responsePersonListItem.setOtherDuties(accountRoleVO.getOtherDuties());
                }
            }

            // 设置账号的过期时间和头像
            SaasAccountListItemVO saasAccountListItemVO = accountInfoMap.get(responsePersonListItem.getAccountId());
            if (saasAccountListItemVO != null) {
                responsePersonListItem.setHeadPortrait(saasAccountListItemVO.getHeadPortrait());
                String validLast = saasAccountListItemVO.getValidLast();
                if (ExpireTypeEnum.EXPIRY_DATE.getType().equals(validLast)) {
                    responsePersonListItem.setExpireDate(saasAccountListItemVO.getValidEndTime());
                }
            }

            // 设置员工类型
            String type = responsePersonListItem.getPersonType();
            responsePersonListItem.setPersonTypeVO(personServiceCommonTool.getPersonTypeVO(type));

            // 设置专业
            String profession = responsePersonListItem.getProfession();
            responsePersonListItem.setProfessions(getProfessionVoList(profession));

            // 设置所属部门
            List<WorkResume> personWorkResumes = workResumes.stream().
                    filter(workResume -> responsePersonListItem.getId().equals(workResume.getPersonId())).
                    filter(workResume -> StringUtils.isBlank(hiredState)
                            || hiredState.equals(workResume.getHiredState())).
                    filter(workResume -> StringUtils.isBlank(enableState)
                            || enableState.equals(workResume.getEnableState())).
                    collect(Collectors.toList());
            if (StringUtils.isNotBlank(depId)) {
                List<WorkResume> currentWorkResumes = personWorkResumes.stream().
                        filter(workResume -> depId.equals(workResume.getDepId())
                                && responsePersonListItem.getId().equals(workResume.getPersonId())).
                        collect(Collectors.toList());
                if (!CollectionUtils.isEmpty(currentWorkResumes)) {
                    WorkResume currentWorkResume = currentWorkResumes.get(0);
                    responsePersonListItem.setIsLeader(currentWorkResume.getIsLeader());
                    responsePersonListItem.setEnableState(currentWorkResume.getEnableState());
                    responsePersonListItem.setHiredState(currentWorkResume.getHiredState());
                }
            }
            responsePersonListItem.setDeps(getDepSimpleObjVoList(personWorkResumes));
        }

        result.setRecords(responsePersonListItems);
        result.setTotal(total);
        return result;
    }

    /**
     * 根据专业id获取专业信息
     *
     * @param profession 专业id id1,id2
     * @return 专业信息列表
     * @author lixing
     * @version V1.0 2021/4/1 2:46 下午
     */
    private List<SimpleObjVO> getProfessionVoList(String profession) {
        List<SimpleObjVO> professions = Lists.newArrayList();
        if (StringUtils.isNotBlank(profession)) {
            String[] professionArr = profession.split(",");
            List<String> professionIds = Arrays.asList(professionArr);
            professions = professionService.queryProfessionInfoByProfessionIds(professionIds);
        }
        return professions;
    }

    @Override
    public List<Person> nameQuickSearch(NameQuickSearchDTO nameQuickSearchDTO) {
        return personMapper.queryPersonNameList(nameQuickSearchDTO);
    }


    @Override
    public ResponsePersonItemVO queryPersonDetail(String id) {
        return queryPersonDetail(id, null);
    }

    @Override
    public ResponsePersonItemVO queryPersonDetail(String id, String depId) {
        Person person = queryPersonProfile(id);
        return fillPersonInfo(depId, person);
    }

    /**
     * 填充人员详情信息
     *
     * @param depId  部门id
     * @param person 人员实体类
     * @return 补充后的人员信息
     * @author lixing
     * @version V1.0 2021/4/29 10:52 上午
     */
    private ResponsePersonItemVO fillPersonInfo(String depId, Person person) {
        if (person == null) {
            return new ResponsePersonItemVO();
        }
        // 设置人员的基本信息
        ResponsePersonItemVO responsePersonItemVO = ConvertPersonTool.INSTANCE.convert2ResponseItemDTO(person);

        // 设置人员账号信息
        String accountId = person.getAccountId();
        SaasAccountListItemVO saasAccountListItemVO = saasAccountService.querySaasAccountDetail(accountId);
        responsePersonItemVO.setMail(saasAccountListItemVO.getMail());
        responsePersonItemVO.setPhoneNum(saasAccountListItemVO.getPhoneNum());
        responsePersonItemVO.setHeadPortrait(saasAccountListItemVO.getHeadPortrait());
        if (ExpireTypeEnum.EXPIRY_DATE.getType().equals(saasAccountListItemVO.getValidLast())) {
            responsePersonItemVO.setExpireDate(saasAccountListItemVO.getValidEndTime());
        }


        // 设置人员岗位角色信息
        Map<String, AccountRoleVO> accountRoleVoMap = saasAccountRoleService.
                queryAccountRoleVoMapByAccountIdList(Lists.newArrayList(accountId));
        if (accountRoleVoMap != null) {
            AccountRoleVO accountRoleVO = accountRoleVoMap.get(accountId);
            if (accountRoleVO != null) {
                responsePersonItemVO.setMainDuty(accountRoleVO.getMainDuty());
                responsePersonItemVO.setOtherDuties(accountRoleVO.getOtherDuties());
                responsePersonItemVO.setOtherRoles(accountRoleVO.getOtherRoles());
            }
        }

        // 设置项目
        List<SaasAccountProject> saasAccountProjects = saasAccountProjectService.
                querySaasAccountProjectListByAccountId(accountId);
        if (!CollectionUtils.isEmpty(saasAccountProjects)) {
            List<String> projectIds = saasAccountProjects.stream().
                    map(SaasAccountProject::getProjectId).collect(Collectors.toList());
            List<SaasProject> saasProjects = saasProjectService.queryProjectList(projectIds);
            List<ProjectVO> projectVoList = ConvertPersonTool.INSTANCE.convert2ProjectVoList(saasProjects);
            responsePersonItemVO.setProjects(projectVoList);
        }

        // 设置员工类型
        String type = person.getPersonType();
        responsePersonItemVO.setPersonTypeVO(personServiceCommonTool.getPersonTypeVO(type));

        // 设置专业
        String profession = person.getProfession();
        responsePersonItemVO.setProfessions(getProfessionVoList(profession));

        // 设置证件类型
        String certificateType = person.getCertificateType();
        responsePersonItemVO.setCertificateTypeVO(personServiceCommonTool.getCertificateTypeVO(certificateType));

        // 设置直接上级
        String leader = person.getLeader();
        responsePersonItemVO.setLeaderVO(getLeaderVO(leader));

        // 设置所属部门
        List<WorkResume> workResumes = workResumeService.queryWorkResumeListByPersonIdList(
                Lists.newArrayList(person.getId()));
        responsePersonItemVO.setDeps(getDepSimpleObjVoList(workResumes));

        if (StringUtils.isNotBlank(depId)) {
            // 设置人员的在职状态和启用状态
            List<WorkResume> currentDepWorkResumes = workResumes.stream().filter(
                    workResume -> depId.equals(workResume.getDepId())
            ).collect(Collectors.toList());
            if (!CollectionUtils.isEmpty(currentDepWorkResumes)) {
                WorkResume currentWorkResume = currentDepWorkResumes.get(0);
                responsePersonItemVO.setHiredState(currentWorkResume.getHiredState());
                responsePersonItemVO.setEnableState(currentWorkResume.getEnableState());
            }
        }

        // 设置员工的集团部门
        responsePersonItemVO.setGroupDep(departmentService.getGroupDep());

        return responsePersonItemVO;
    }

    /**
     * 根据工作信息获取人员所属部门
     *
     * @param workResumes 工作信息列表
     * @return 所属部门列表
     * @author lixing
     * @version V1.0 2021/4/1 6:00 下午
     */
    public List<DepSimpleObjVO> getDepSimpleObjVoList(List<WorkResume> workResumes) {
        if (CollectionUtils.isEmpty(workResumes)) {
            return Lists.newArrayList();
        }
        List<String> depIds = workResumes.stream().map(WorkResume::getDepId).collect(Collectors.toList());
        return departmentService.getDepInfoList(depIds);
    }

    @Override
    public SimpleObjVO getLeaderVO(String leaderId) {
        if (StringUtils.isBlank(leaderId)) {
            return new SimpleObjVO();
        }
        Person person = queryPersonProfile(leaderId);
        return new SimpleObjVO(leaderId, person.getName());
    }

    @Override
    public LatestJobNumberVO queryLatestJobNumber() {
        LatestJobNumberVO latestJobNumberVO = new LatestJobNumberVO();

        QueryWrapper<Person> personQueryWrapper = personServiceCommonTool.getDefaultPersonQueryWrapper();
        personQueryWrapper.ne(Person.PROP_JOB_NUMBER, "");
        personQueryWrapper.orderByDesc(Person.PROP_CREATIONTIME);

        IPage<Person> pageParam = new Page<>(1, 1, true);
        IPage<Person> results = getBaseMapper().selectPage(pageParam, personQueryWrapper);
        List<Person> records = results.getRecords();
        if (!CollectionUtils.isEmpty(records)) {
            Person person = records.get(0);
            latestJobNumberVO.setJobNumber(person.getJobNumber());
        }

        return latestJobNumberVO;
    }

    @Override
    public List<Person> queryByProfessionId(String professionId) {
        if (StringUtils.isBlank(professionId)) {
            throw new IllegalArgumentException("根据专业查询人员，专业id不可为空");
        }
        LambdaQueryWrapper<Person> personLambdaQueryWrapper = new LambdaQueryWrapper<>();
        personLambdaQueryWrapper.
                like(Person::getProfession, "%" + professionId + "%").
                eq(Person::getValid, ValidEnum.TRUE.getType());
        return list(personLambdaQueryWrapper);
    }

    @Override
    public List<Person> queryByLeader(Long leaderId) {
        if (leaderId == null) {
            throw new IllegalArgumentException("根据直接上级查询人员，直接上级id不可为空");
        }
        LambdaQueryWrapper<Person> personLambdaQueryWrapper = new LambdaQueryWrapper<>();
        personLambdaQueryWrapper.
                eq(Person::getLeader, leaderId).
                eq(Person::getValid, ValidEnum.TRUE.getType());
        return list(personLambdaQueryWrapper);
    }

    @Override
    public IPage<ResponsePersonListItemVO> pageQueryByNameOrUserName(PageQueryPersonByNameOrUserNameDTO pageQueryPersonDTO) {
        List<Person> people = personMapper.queryPersonListByNameOrUserName(pageQueryPersonDTO);
        int total = personMapper.queryCountByNameOrUserName(pageQueryPersonDTO);
        String hiredState = pageQueryPersonDTO.getHiredState() == null ?
                "" : pageQueryPersonDTO.getHiredState().toString();
        String enableState = pageQueryPersonDTO.getEnableState() == null ?
                "" : pageQueryPersonDTO.getEnableState().toString();
        return packagePageResult(people, total, null, hiredState, enableState);
    }

    @Override
    public IPage<ResponsePersonListItemVO> queryByUserName(QueryByUserNameDTO queryByUserNameDTO) {
        QueryWrapper<Person> queryWrapper = personServiceCommonTool.getDefaultPersonQueryWrapper();
        queryWrapper.eq(Person.PROP_USERNAME, queryByUserNameDTO.getUsername());
        List<Person> result = list(queryWrapper);
        return packagePageResult(result, result.size());
    }


    @Override
    public IPage<ResponsePersonListItemVO> queryByName(QueryByNameDTO queryByNameDTO) {
        QueryWrapper<Person> queryWrapper = personServiceCommonTool.getDefaultPersonQueryWrapper();
        queryWrapper.like(Person.PROP_NAME, queryByNameDTO.getName());
        List<Person> result = list(queryWrapper);
        return packagePageResult(result, result.size());
    }

    @Override
    public IPage<ResponsePersonListItemVO> queryDetailByIds(List<String> ids) {
        List<Person> people = queryByIds(ids);
        if (CollectionUtils.isEmpty(people)) {
            IPage<ResponsePersonListItemVO> result = new Page<>();
            result.setRecords(Lists.newArrayList());
            return result;
        }
        return packagePageResult(people, people.size());
    }

    @Override
    public ResponsePersonItemVO queryDetailByAccountId(String accountId, String depId) {
        Person person = queryByAccountId(accountId);
        return fillPersonInfo(depId, person);
    }

    @Override
    public String queryAccountId(String id) {
        Person person = queryPersonProfile(id);
        return person.getAccountId();
    }

    @Override
    public IPage<ResponsePersonListItemVO> queryByDepId(PageQueryByDepIdDTO pageQueryByDepIdDTO) {
        List<String> depIds = Lists.newArrayList(pageQueryByDepIdDTO.getDepId());
        // 如果包含下级部门，查询下级部门。
        String containsSub = pageQueryByDepIdDTO.getContainsSub();
        if (BoolEnum.TRUE.getType().equals(containsSub)) {
            Department department = departmentService.queryDepartmentDetail(pageQueryByDepIdDTO.getDepId());
            String fullPath = department.getFullPath();
            List<Department> departments = departmentService.queryDepsContainsFullPath(fullPath);
            depIds = departments.stream().map(Department::getId).collect(Collectors.toList());
        }

        // 查询这些部门下的人员
        PageQueryByDepIdsDTO pageQueryByDepIdsDTO = ConvertPersonTool.INSTANCE.
                convert2PageQueryByDepIdsDTO(pageQueryByDepIdDTO);
        pageQueryByDepIdsDTO.setDepIds(depIds);
        List<Person> people = personMapper.queryByDepIds(pageQueryByDepIdsDTO);
        int total = personMapper.queryCountByDepIds(pageQueryByDepIdsDTO);

        // 处理返回结果
        if (!BoolEnum.TRUE.getType().equals(containsSub)) {
            return packagePageResult(people, total, pageQueryByDepIdDTO.getDepId());
        }
        return packagePageResult(people, total);
    }

    @Override
    public List<SimpleObjVO> queryAllPersonName(QueryAllPersonNameDTO queryAllPersonNameDTO) {
        List<Person> people;
        LambdaQueryWrapper<Person> personLambdaQueryWrapper = new LambdaQueryWrapper<>();
        personLambdaQueryWrapper.orderBy(true, true, Person::getNamePinyin);
        if (!StringUtils.isBlank(queryAllPersonNameDTO.getName())) {
            personLambdaQueryWrapper.like(Person::getName, queryAllPersonNameDTO.getName());
        }
        people = list(personLambdaQueryWrapper);

        return people.stream().map(person -> {
            SimpleObjVO simpleObjVO = new SimpleObjVO();
            simpleObjVO.setId(person.getId());
            simpleObjVO.setName(person.getName());
            return simpleObjVO;
        }).collect(Collectors.toList());
    }

    @Override
    public IPage<AccountInfoVO> pageQueryByRoleIds(PageQueryByRoleIdsDTO pageQueryByRoleIdsDTO) {
        IPage<AccountInfoVO> result = new Page<>();
        personServiceCommonTool.emptyPageResult(result);

        // 角色id为空，返回空结果
        List<String> roleIds = pageQueryByRoleIdsDTO.getRoleIds();
        if (CollectionUtils.isEmpty(roleIds)) {
            return result;
        }

        // 根据角色id查询角色关联的账号
        PageQuerySaasAccountByRoleIdsDTO pageQuerySaasAccountByRoleIdsDTO = ConvertPersonTool.INSTANCE.
                convert2PageQuerySaasAccountByRoleIdsDTO(pageQueryByRoleIdsDTO);
        pageQuerySaasAccountByRoleIdsDTO.setPageInfo();
        FmResponseContent<List<SaasAccountListItemVO>> pageResult = saasAccountService.pageQueryAccountsByRoleIds(
                pageQuerySaasAccountByRoleIdsDTO);
        Integer total = pageResult.getCount();

        if (total <= 0) {
            return result;
        }

        List<SaasAccountListItemVO> content = pageResult.getContent();
        List<String> accountIds = Lists.newArrayList();
        if (!CollectionUtils.isEmpty(content)) {
            accountIds = content.stream().map(SaasAccountListItemVO::getId).collect(Collectors.toList());
        }

        // 查询人员信息
        QueryWrapper<Person> queryWrapper = personServiceCommonTool.getDefaultPersonQueryWrapper();
        if (CollectionUtils.isEmpty(accountIds)) {
            return result;
        }
        queryWrapper.in(Person.PROP_ACCOUNT_ID, accountIds);
        List<Person> persons = list(queryWrapper);
        Map<String, Person> accountIdPersonMap = new HashMap<>();
        if (!CollectionUtils.isEmpty(persons)) {
            accountIdPersonMap = persons.stream().collect(Collectors.toMap(
                    Person::getAccountId,
                    person -> person,
                    (k1, k2) -> k1
            ));
        }

        List<AccountInfoVO> accountInfoVOS = Lists.newArrayList();
        for (SaasAccountListItemVO saasAccountListItemVO : content) {
            Person person = accountIdPersonMap.get(saasAccountListItemVO.getId());
            AccountInfoVO accountInfoVO = ConvertPersonTool.INSTANCE.convert2AccountInfoVO(saasAccountListItemVO, person);
            accountInfoVOS.add(accountInfoVO);
        }

        result.setRecords(accountInfoVOS);
        result.setTotal(total);
        return result;
    }

    @Override
    public IPage<ResponsePersonListItemVO> pageQueryByAccountIds(List<String> accountIds) {
        QueryWrapper<Person> queryWrapper = personServiceCommonTool.getDefaultPersonQueryWrapper();
        queryWrapper.in(Person.PROP_ACCOUNT_ID, accountIds);
        List<Person> result = list(queryWrapper);
        return packagePageResult(result, result.size());
    }
}
