package com.persagy.fm.person.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.persagy.fm.common.constant.enums.ValidEnum;
import com.persagy.fm.common.context.DefaultAppContext;
import com.persagy.fm.common.model.vo.SimpleObjVO;
import com.persagy.fm.person.constant.enums.CertificateTypeEnum;
import com.persagy.fm.person.constant.enums.PersonTypeEnum;
import com.persagy.fm.person.model.Person;
import com.persagy.fm.person.model.vo.ResponsePersonListItemVO;
import org.apache.poi.ss.formula.functions.T;
import org.assertj.core.util.Lists;
import org.springframework.stereotype.Component;

/**
 * 人员服务通用工具类
 *
 * @author lixing
 * @version V1.0 2021/4/29 5:29 下午
 */
@Component
public class PersonServiceCommonTool {
    /**
     * 如果某些字段没有赋值，使用默认的值
     *
     * @param person 人员实体
     * @author lixing
     * @version V1.0 2021/3/12 12:29 下午
     */
    void setDefaultValue(Person person) {
        person.setCreator(DefaultAppContext.getContext().getAccountId());
    }

    /**
     * 根据员工类型id获取员工类型对象
     *
     * @param type 员工类型id
     * @return 员工类型对象
     * @author lixing
     * @version V1.0 2021/4/1 12:04 下午
     */
    SimpleObjVO getPersonTypeVO(String type) {
        SimpleObjVO personType = new SimpleObjVO();
        personType.setId(type);
        PersonTypeEnum personTypeEnum = PersonTypeEnum.getByType(type);
        if (personTypeEnum != null) {
            personType.setName(personTypeEnum.getDesc());
        }
        return personType;
    }

    /**
     * 根据证件类型id，获取证件类型信息
     *
     * @param certificateType 证件类型id
     * @return 证件类型信息
     * @author lixing
     * @version V1.0 2021/4/6 11:38 上午
     */
    SimpleObjVO getCertificateTypeVO(String certificateType) {
        SimpleObjVO certificateTypeVO = new SimpleObjVO();
        certificateTypeVO.setId(certificateType);
        CertificateTypeEnum certificateTypeEnum = CertificateTypeEnum.getByType(certificateType);
        if (certificateTypeEnum != null) {
            certificateTypeVO.setName(certificateTypeEnum.getDesc());
        }
        return certificateTypeVO;
    }

    /**
     * 获取人员默认查询参数对象
     *
     * @return QueryWrapper
     * @author lixing
     * @version V1.0 2021/4/25 3:07 下午
     */
    QueryWrapper<Person> getDefaultPersonQueryWrapper() {
        QueryWrapper<Person> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(Person.PROP_VALID, ValidEnum.TRUE.getType());
        return queryWrapper;
    }

    /**
     * 置空分页结果对象
     *
     * @param result 分页结果
     * @author lixing
     * @version V1.0 2021/4/30 10:32 上午
     */
    public void emptyPageResult(IPage result) {
        result.setRecords(Lists.newArrayList());
        result.setTotal(0);
    }
}