package com.persagy.fm.saas.account.service;

import com.persagy.fm.common.response.FmResponseContent;
import com.persagy.fm.saas.account.model.dto.*;
import com.persagy.fm.saas.account.model.vo.SaasAccountListItemVO;

import java.util.List;

/**
 * 运维中心账号接口
 *
 * @author lixing
 * @version V1.0 2021/4/6 2:32 下午
 **/
public interface ISaasAccountService {
    /**
     * 创建账号
     *
     * @param addSaasAccountDTO 创建账号入参
     * @return 账号id
     * @author lixing
     * @version V1.0 2021/4/6 2:53 下午
     */
    String createSaasAccount(AddSaasAccountDTO addSaasAccountDTO);

    /**
     * 查询账号列表
     *
     * @param pageQuerySaasAccountDTO 查询账号入参
     * @return 账号列表
     * @author lixing
     * @version V1.0 2021/4/6 2:56 下午
     */
    List<SaasAccountListItemVO> querySaasAccountList(PageQuerySaasAccountDTO pageQuerySaasAccountDTO);

    /**
     * 分页查询角色关联的账号列表
     *
     * @param pageQuerySaasAccountByRoleIdsDTO 查询条件
     * @return 账号列表
     * @author lixing
     * @version V1.0 2021/3/23 11:57 上午
     */
    FmResponseContent<List<SaasAccountListItemVO>> pageQueryAccountsByRoleIds(
            PageQuerySaasAccountByRoleIdsDTO pageQuerySaasAccountByRoleIdsDTO);

    /**
     * 根据账号id列表查询账号信息
     *
     * @param accountIds 账号id列表
     * @return 账号列表
     * @author lixing
     * @version V1.0 2021/5/6 9:59 上午
     */
    List<SaasAccountListItemVO> querySaasAccountListByAccountIds(List<String> accountIds);

    /**
     * 查询账号详情
     *
     * @param accountId 账号id
     * @return 账号详情
     * @author lixing
     * @version V1.0 2021/4/6 4:43 下午
     */
    SaasAccountListItemVO querySaasAccountDetail(String accountId);

    /**
     * 禁用账号
     *
     * @param deleteSaasAccountDTO 禁用账号入参
     * @author lixing
     * @version V1.0 2021/4/6 2:57 下午
     */
    void disableAccount(DeleteSaasAccountDTO deleteSaasAccountDTO);

    /**
     * 启用账号
     *
     * @param enableSaasAccountDTO 启用账号入参
     * @author lixing
     * @version V1.0 2021/4/6 2:57 下午
     */
    void enableAccount(EnableSaasAccountDTO enableSaasAccountDTO);

    /**
     * 更新账号信息
     *
     * @param updateSaasAccountDTO 更新账号入参
     * @author lixing
     * @version V1.0 2021/4/6 4:34 下午
     */
    void updateSaasAccount(UpdateSaasAccountDTO updateSaasAccountDTO);
}
