package com.persagy.fm.saas.accountproject.service.impl;

import com.persagy.fm.common.context.AppContext;
import com.persagy.fm.common.response.FmResponseContent;
import com.persagy.fm.saas.accountproject.client.SaasAccountProjectClient;
import com.persagy.fm.saas.accountproject.model.SaasAccountProject;
import com.persagy.fm.saas.accountproject.model.dto.*;
import com.persagy.fm.saas.accountproject.service.ISaasAccountProjectService;
import com.persagy.fm.saas.project.model.dto.UpsertSaasProjectDTO;
import org.apache.commons.lang3.StringUtils;
import org.assertj.core.util.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.List;

/**
 * 账号-集团项目关联信息(SaasAccountProject) service层
 *
 * @author lixing
 * @version V1.0 2021-03-26 15:15:40
 */
@Service
public class SaasAccountProjectServiceImpl implements ISaasAccountProjectService {
    @Autowired
    SaasAccountProjectClient saasAccountProjectClient;

    @Override
    public String createSaasAccountProject(AddSaasAccountProjectDTO addSaasAccountProjectDTO) {
        addSaasAccountProjectDTO.setDefaultValueNoAccountId();
        FmResponseContent<String> saasAccountProject = saasAccountProjectClient.createSaasAccountProject(addSaasAccountProjectDTO);
        return saasAccountProject.getContent();
    }

    @Override
    public void deleteSaasAccountProject(String accountId) {
        DeleteSaasAccountProjectDTO deleteSaasAccountProjectDTO = new DeleteSaasAccountProjectDTO();
        deleteSaasAccountProjectDTO.setDefaultValueNoAccountId();
        deleteSaasAccountProjectDTO.setAccountId(accountId);
        saasAccountProjectClient.deleteSaasAccountProject(deleteSaasAccountProjectDTO);
    }

    @Override
    public List<SaasAccountProject> querySaasAccountProjectList(QuerySaasAccountProjectDTO querySaasAccountProjectDTO) {
        querySaasAccountProjectDTO.setDefaultValueNoAccountId();
        FmResponseContent<List<SaasAccountProject>> responseContent = saasAccountProjectClient.querySaasAccountProjectList(querySaasAccountProjectDTO);
        return responseContent.getContent();
    }

    @Override
    public List<SaasAccountProject> querySaasAccountProjectListByAccountId(String accountId) {
        if (StringUtils.isBlank(accountId)) {
            return null;
        }
        QuerySaasAccountProjectDTO querySaasAccountProjectDTO = new QuerySaasAccountProjectDTO();
        querySaasAccountProjectDTO.setAccountId(accountId);
        return querySaasAccountProjectList(querySaasAccountProjectDTO);
    }

    @Override
    public void resetSaasAccountProject(String accountId, List<UpsertSaasProjectDTO> projects) {
        List<ResetAccountProjectItem> auths = Lists.newArrayList();
        if (!CollectionUtils.isEmpty(projects)) {
            projects.forEach(project -> {
                ResetAccountProjectItem resetAccountProjectItem = new ResetAccountProjectItem();
                resetAccountProjectItem.setProjectId(project.getProjectId());
                resetAccountProjectItem.setAreaId(project.getAreaId());
                resetAccountProjectItem.setGroupCode(AppContext.getContext().getGroupCode());
                auths.add(resetAccountProjectItem);
            });

            ResetSaasAccountProjectDTO resetSaasAccountProjectDTO = new ResetSaasAccountProjectDTO();
            resetSaasAccountProjectDTO.setDefaultValueNoAccountId();
            resetSaasAccountProjectDTO.setAccountId(accountId);
            resetSaasAccountProjectDTO.setAuths(auths);
            saasAccountProjectClient.resetSaasAccountProject(resetSaasAccountProjectDTO);
        } else {
            QuerySaasAccountProjectDTO querySaasAccountProjectDTO = new QuerySaasAccountProjectDTO();
            querySaasAccountProjectDTO.setDefaultValueNoAccountId();
            querySaasAccountProjectDTO.setAccountId(accountId);
            FmResponseContent<List<SaasAccountProject>> responseContent = saasAccountProjectClient.
                    querySaasAccountProjectList(querySaasAccountProjectDTO);
            if (responseContent.getCount() > 0) {
                DeleteSaasAccountProjectDTO deleteSaasAccountProjectDTO = new DeleteSaasAccountProjectDTO();
                deleteSaasAccountProjectDTO.setDefaultValueNoAccountId();
                deleteSaasAccountProjectDTO.setAccountId(accountId);
                saasAccountProjectClient.deleteSaasAccountProject(deleteSaasAccountProjectDTO);
            }
        }

    }
}
