package com.persagy.fm.saas.accountrole.client;

import com.persagy.fm.common.client.FeignConfig;
import com.persagy.fm.common.response.FmResponseContent;
import com.persagy.fm.common.response.FmResponseMsg;
import com.persagy.fm.saas.account.model.dto.AddSaasAccountDTO;
import com.persagy.fm.saas.account.model.dto.PageQuerySaasAccountDTO;
import com.persagy.fm.saas.account.model.dto.UpdateSaasAccountDTO;
import com.persagy.fm.saas.account.model.vo.SaasAccountListItemVO;
import com.persagy.fm.saas.accountrole.client.fallback.SaasAccountRoleClientFallbackFactory;
import com.persagy.fm.saas.accountrole.model.SaasAccountRole;
import com.persagy.fm.saas.accountrole.model.dto.AddSaasAccountRoleDTO;
import com.persagy.fm.saas.accountrole.model.dto.DeleteSaasAccountRoleDTO;
import com.persagy.fm.saas.accountrole.model.dto.QuerySaasAccountRoleDTO;
import com.persagy.fm.saas.accountrole.model.dto.ResetSaasAccountRoleDTO;
import com.persagy.fm.saas.project.constant.FeignClientNameConstants;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.List;

/**
 * 运维平台账号角色关联接口feign客户端
 *
 * @author lixing
 * @version V1.0 2021/3/22 2:13 下午
 **/
@FeignClient(name = FeignClientNameConstants.SAAS, fallbackFactory = SaasAccountRoleClientFallbackFactory.class,
        configuration = FeignConfig.class)
public interface SaasAccountRoleClient {
    /**
     * 查询账号角色关联列表
     *
     * @param querySaasAccountRoleDTO 查询条件
     * @return 账号角色关联列表
     * @author lixing
     * @version V1.0 2021/3/23 11:57 上午
     */
    @PostMapping("/accountRole/querySaasRoleMenuList")
    FmResponseContent<List<SaasAccountRole>> querySaasAccountRoleList(@RequestBody QuerySaasAccountRoleDTO querySaasAccountRoleDTO);

    /**
     * 创建账号角色关联
     *
     * @param addSaasAccountRoleDTO 创建账号角色关联入参
     * @return 账号角色关联id
     * @author lixing
     * @version V1.0 2021/3/23 11:57 上午
     */
    @PostMapping("/accountRole/createSaasAccountRole")
    FmResponseContent<String> createSaasAccountRole(@RequestBody AddSaasAccountRoleDTO addSaasAccountRoleDTO);

    /**
     * 删除账号角色关联
     *
     * @param deleteSaasAccountRoleDTO 删除账号角色关联入参
     * @author lixing
     * @return FmResponseMsg
     * @version V1.0 2021/3/23 11:57 上午
     */
    @PostMapping("/accountRole/deleteSaasAccountRole")
    FmResponseMsg deleteSaasAccountRole(@RequestBody DeleteSaasAccountRoleDTO deleteSaasAccountRoleDTO);

    /**
     * 重置账号与角色的关联
     *
     * @param resetSaasAccountRoleDTO 重置账号与角色的关联入参
     * @return FmResponseMsg
     * @author lixing
     * @version V1.0 2021/4/8 2:53 下午
     */
    @PostMapping("/accountRole/resetSaasAccountRole")
    FmResponseMsg resetSaasAccountRole(@RequestBody ResetSaasAccountRoleDTO resetSaasAccountRoleDTO);
}
