package com.persagy.fm.saas.role.client;

import com.persagy.fm.common.client.FeignConfig;
import com.persagy.fm.common.response.FmResponseContent;
import com.persagy.fm.common.response.FmResponseMsg;
import com.persagy.fm.saas.project.constant.FeignClientNameConstants;
import com.persagy.fm.saas.role.client.fallback.SaasRoleClientFallbackFactory;
import com.persagy.fm.saas.role.model.SaasRole;
import com.persagy.fm.saas.role.model.dto.DeleteSaasRoleDTO;
import com.persagy.fm.saas.role.model.dto.PageQuerySaasRoleDTO;
import com.persagy.fm.saas.role.model.dto.QuerySaasRoleByNameDTO;
import com.persagy.fm.saas.role.model.dto.QuerySaasRoleDTO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.List;

/**
 * 运维系统角色接口
 *
 * @author lixing
 * @version V1.0 2021/3/22 2:13 下午
 **/
@FeignClient(name = FeignClientNameConstants.SAAS, fallbackFactory = SaasRoleClientFallbackFactory.class,
        configuration = FeignConfig.class)
public interface SaasRoleClient {
    /**
     * 分页查询账号列表
     *
     * @param pageQuerySaasRoleDTO 分页查询条件
     * @return 角色列表
     * @author lixing
     * @version V1.0 2021/3/23 11:57 上午
     */
    @PostMapping("/role/queryRolePageList")
    FmResponseContent<List<SaasRole>> queryRolePageList(@RequestBody PageQuerySaasRoleDTO pageQuerySaasRoleDTO);

    /**
     * 查询账号列表
     *
     * @param querySaasRoleDTO 查询入参
     * @return 角色列表
     * @author lixing
     * @version V1.0 2021/4/1 10:05 上午
     */
    @PostMapping("/role/querySaasRoleList")
    FmResponseContent<List<SaasRole>> queryRoleList(@RequestBody QuerySaasRoleDTO querySaasRoleDTO);

    /**
     * 查询账号列表
     *
     * @param querySaasRoleByNameDTO 查询入参
     * @return 角色列表
     * @author lixing
     * @version V1.0 2021/4/1 10:05 上午
     */
    @PostMapping("/role/querySaasRoleByName")
    FmResponseContent<List<SaasRole>> querySaasRoleByName(@RequestBody QuerySaasRoleByNameDTO querySaasRoleByNameDTO);

    /**
     * 创建角色
     *
     * @param saasRole 创建角色入参
     * @return 角色id
     * @author lixing
     * @version V1.0 2021/3/23 11:57 上午
     */
    @PostMapping("/role/createSaasRole")
    FmResponseContent<String> createSaasRole(@RequestBody SaasRole saasRole);

    /**
     * 更新角色
     *
     * @param saasRole 更新角色入参
     * @return FmResponseMsg
     * @author lixing
     * @version V1.0 2021/3/23 11:57 上午
     */
    @PostMapping("/role/updateSaasRole")
    FmResponseMsg updateSaasRole(@RequestBody SaasRole saasRole);

    /**
     * 删除角色
     *
     * @param deleteSaasRoleDTO 删除角色入参
     * @return FmResponseMsg
     * @author lixing
     * @version V1.0 2021/3/23 11:57 上午
     */
    @PostMapping("/role/deleteSaasRole")
    FmResponseMsg deleteSaasRole(@RequestBody DeleteSaasRoleDTO deleteSaasRoleDTO);
}
