package com.persagy.fm.saas.role.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.persagy.fm.common.response.CommonResult;
import com.persagy.fm.common.response.FmResponseItem;
import com.persagy.fm.common.response.PageList;
import com.persagy.fm.common.utils.ResultHelper;
import com.persagy.fm.saas.role.model.ConvertSaasRoleTool;
import com.persagy.fm.saas.role.model.SaasRole;
import com.persagy.fm.saas.role.model.dto.*;
import com.persagy.fm.saas.role.model.vo.SaasRoleIdVO;
import com.persagy.fm.saas.role.model.vo.SaasRoleListItemVO;
import com.persagy.fm.saas.role.service.ISaasRoleService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;

/**
 * @author lixing
 * @version V1.0 2021-03-22 19:04:01
 */
@Api(tags = "岗位角色管理")
@Validated
@RestController
@RequestMapping("saasRoles")
public class SaasRoleController {
    @Autowired
    private ISaasRoleService saasRoleService;

    @ApiOperation(value = "创建")
    @PostMapping("/create")
    public CommonResult<SaasRoleIdVO> createSaasRole(
            @Valid @RequestBody AddSaasRoleDTO addSaasRoleDTO) {
        String roleId = saasRoleService.createSaasRole(addSaasRoleDTO);
        SaasRoleIdVO saasRoleIdVO = new SaasRoleIdVO();
        saasRoleIdVO.setId(roleId);
        return ResultHelper.single(saasRoleIdVO);
    }

    @ApiOperation(value = "详情")
    @PostMapping("/get")
    public CommonResult<SaasRoleListItemVO> querySaasRoleDetail(
            @Valid @RequestBody QuerySaasRoleDetailDTO querySaasRoleDetailDTO) {
        SaasRole saasRole = saasRoleService.querySaasRoleDetail(querySaasRoleDetailDTO.getId());
        SaasRoleListItemVO saasRoleListItemVO = convertSaasRole2SaasRoleListItemVO(saasRole);
        return ResultHelper.single(saasRoleListItemVO);
    }


    @ApiOperation(value = "更新")
    @PostMapping("/update")
    public CommonResult updateSaasRole(
            @Valid @RequestBody UpdateSaasRoleDTO updateSaasRoleDTO) {
        saasRoleService.updateSaasRole(updateSaasRoleDTO);
        return ResultHelper.success("更新成功");
    }


    @ApiOperation(value = "删除")
    @PostMapping("/delete")
    public CommonResult deleteSaasRole(
            @RequestBody @Valid DeleteSaasRoleDTO deleteSaasRoleDTO) {
        saasRoleService.deleteSaasRole(deleteSaasRoleDTO.getId());
        return ResultHelper.success("删除成功");
    }


    //    @ApiOperation(value = "列表")
    //    @PostMapping("/query")
    //    public CommonResult<List<ResponseSaasRoleListItemVO>> querySaasRole(
    //            @Valid @RequestBody QuerySaasRoleDTO querySaasRoleDTO) {
    //        List<SaasRole> saasRoleList = saasRoleService.querySaasRoleList(querySaasRoleDTO);
    //        List<ResponseSaasRoleListItemVO> resultList = ConvertSaasRoleTool.INSTANCE.convert2List(saasRoleList);
    //        return ResultHelper.multi(resultList);
    //    }

    @ApiOperation(value = "列表, 分页查询")
    @PostMapping("/query")
    public CommonResult<PageList<SaasRoleListItemVO>> querySaasRole(
            @Valid @RequestBody PageQuerySaasRoleDTO pageQuerySaasRoleDTO) {
        IPage<SaasRole> pagedList = saasRoleService.pageQuerySaasRole(pageQuerySaasRoleDTO);
        IPage<SaasRoleListItemVO> pagedResultList = pagedList.convert(item -> {
            try {
                return convertSaasRole2SaasRoleListItemVO(item);
            } catch (Exception e) {
                throw new IllegalArgumentException("分页查询，SaasRole实体类转换为列表对象发生异常", e);
            }
        });
        return ResultHelper.multi(pagedResultList);
    }

    /**
     * 将saasRole转换为SaasRoleListItemVO
     *
     * @param saasRole 角色对象
     * @return SaasRoleListItemVO
     * @author lixing
     * @version V1.0 2021/4/29 2:35 下午
     */
    private SaasRoleListItemVO convertSaasRole2SaasRoleListItemVO(SaasRole saasRole) {
        if (saasRole == null) {
            return null;
        }
        SaasRoleListItemVO saasRoleListItemVO = ConvertSaasRoleTool.INSTANCE.convert2ResponseListItemDTO(saasRole);
        Integer countFunction = saasRole.getCountFunction();
        Integer countMenu = saasRole.getCountMenu();
        countFunction = countFunction == null ? 0 : countFunction;
        countMenu = countMenu == null ? 0 : countMenu;
        saasRoleListItemVO.setRelatedFunCount(countFunction + countMenu);
        return saasRoleListItemVO;
    }

    @ApiOperation(value = "根据角色名称查询")
    @PostMapping("/queryByName")
    public CommonResult<PageList<SaasRole>> querySaasRoleByName(
            @Valid @RequestBody QuerySaasRoleByNameDTO querySaasRoleByNameDTO) {
        List<SaasRole> saasRoles = saasRoleService.queryByName(querySaasRoleByNameDTO);
        return ResultHelper.multi(saasRoles);
    }
}

