package com.persagy.fm.workresume.model;

import com.persagy.fm.workresume.model.dto.AddWorkResumeDTO;
import com.persagy.fm.workresume.model.dto.UpdateWorkResumeDTO;
import com.persagy.fm.workresume.model.vo.ResponseWorkResumeItemVO;
import com.persagy.fm.workresume.model.vo.ResponseWorkResumeListItemVO;
import org.mapstruct.Mapper;
import org.mapstruct.MappingTarget;
import org.mapstruct.NullValueCheckStrategy;
import org.mapstruct.NullValueMappingStrategy;
import org.mapstruct.factory.Mappers;

import java.util.List;

/**
 * 工作信息(WorkResume) dto、vo、do转换工具类
 *
 * @author lixing
 * @version V1.0 2021-03-15 17:20:08 2021-03-15 17:20:08
 */
@Mapper(nullValueMappingStrategy = NullValueMappingStrategy.RETURN_DEFAULT,
        nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS)
public interface ConvertWorkResumeTool {

    ConvertWorkResumeTool INSTANCE = Mappers.getMapper(ConvertWorkResumeTool.class);

    /**
     * do转换为ResponseItemVO
     *
     * @param workResume do对象
     * @return ResponseItemVO
     * @author lixing
     * @version V1.0 2021-03-15 17:20:08
     */
    ResponseWorkResumeItemVO convert2ResponseItemDTO(WorkResume workResume);

    /**
     * do转换为ResponseListItemVO
     *
     * @param workResume do对象
     * @return ResponseListItemVO
     * @author lixing
     * @version V1.0 2021-03-15 17:20:08
     */
    ResponseWorkResumeListItemVO convert2ResponseListItemDTO(WorkResume workResume);

    /**
     * do列表转换为ResponseListItemVO列表
     *
     * @param workResumeList do列表
     * @return ResponseListItemVO列表
     * @author lixing
     * @version V1.0 2021-03-15 17:20:08
     */
    List<ResponseWorkResumeListItemVO> convert2List(List<WorkResume> workResumeList);

    /**
     * addDTO转换为do
     *
     * @param addWorkResumeDTO addDTO
     * @return 要创建的do对象
     * @author lixing
     * @version V1.0 2021-03-15 17:20:08
     */
    WorkResume convertAddDto2Entity(AddWorkResumeDTO addWorkResumeDTO);

    /**
     * updateDTO转换为实体
     *
     * @param workResume          更新前的do对象
     * @param updateWorkResumeDTO updateDTO
     * @return 更新后的do对象
     * @author lixing
     * @version V1.0 2021-03-15 17:20:08
     */
    WorkResume convertUpdateDto2Entity(@MappingTarget WorkResume workResume, UpdateWorkResumeDTO updateWorkResumeDTO);
}

